#========================================================================================
# package      DE_EPAGES::Customer::t::unit::CustomerService
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::Customer::API::CustomerService.
#========================================================================================
package DE_EPAGES::Customer::t::unit::CustomerService;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Customer::API::CustomerService;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use Test::More;
use Test::Exception;
use strict;

sub test {
    my $self = shift;

    $self->test_getCustomerData();
    $self->test_createCustomer();
    $self->test_createCustomerWithSameCustomerNumber();

    done_testing();
}
sub test_createCustomerWithSameCustomerNumber {
    my $self = shift;
    my $CustomerService = DE_EPAGES::Customer::API::CustomerService->new();
    my $Shop = $self->_createShopWithCustomer();
    my $hRequestBody = {
        'customerNumber' => 'TestCustomer123'
    };
    dies_ok{ $CustomerService->createCustomer($Shop, $hRequestBody)} 'Test passed with Error';

}

sub test_createCustomer {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $CustomerService = DE_EPAGES::Customer::API::CustomerService->new();
    my $Shop = $self->_createShopWithoutCustomer();
    my $hRequestBody = {
        'customerNumber' => 'TestCustomer123'
    };
    my $hCustomerData = $CustomerService->createCustomer($Shop, $hRequestBody);
    my $hExpectedCustomerData = {
        'customerId' => '123-456-7890',
        'customerNumber' => 'TestCustomer123',
    };
    is_deeply($hCustomerData, $hExpectedCustomerData, "$SubTestName - test if expected customer data was returned.");
}

sub test_getCustomerData {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Customer = $self->_createMockedCustomer();

    my $CustomerService = DE_EPAGES::Customer::API::CustomerService->new();
    my $hCustomerData = $CustomerService->getCustomerData($Customer);

    my $hExpectedCustomerData = {
        'customerId' => '123-456-7890',
        'customerNumber' => 'TestCustomer123',
    };

    is_deeply($hCustomerData, $hExpectedCustomerData, "$SubTestName - test if expected customer data was returned.");
}



sub _createMockedCustomer {
    my $self = shift;

    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Customer::API::Object::Customer', {
        'Alias' => 'TestCustomer123',
        'GUID' => '123-456-7890',
    });

    return $Mockify->getMockObject();
}

sub _createMockedCustomerClass {
    my $self = shift;
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Object::API::Object::Class', {});
    $Mockify->addMockWithReturnValueAndParameterCheck('insertObject', $self->_createMockedCustomer(), ['hashref']);
    return $Mockify->getMockObject();
}

sub _createShopWithCustomer {
    my $self = shift;
    my $hAttributes = {
        'CustomerClass' => $self->_createMockedCustomerClass(),
    };
    my $Shop = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', $hAttributes);
    $Shop->addMockWithReturnValueAndParameterCheck('folder', $self->_createCustomerFolderWithCustomer(), ['string']);
    return $Shop->getMockObject();
}

sub _createShopWithoutCustomer {
    my $self = shift;
    my $hAttributes = {
        'CustomerClass' => $self->_createMockedCustomerClass(),
    };
    my $Shop = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', $hAttributes);
    $Shop->addMockWithReturnValueAndParameterCheck('folder', $self->_createCustomerFolderWithoutCustomer(), ['string']);
    return $Shop->getMockObject();
}

sub _createCustomerFolderWithCustomer {
    my $self = shift;
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
        'DE_EPAGES::Object::API::Object::Object',
        []
    );
    $Mockify->addMockWithReturnValueAndParameterCheck('existsChild', 1, ['string']);
    my $Folder = $Mockify->getMockObject();
    $self->{'Customer'} = $Folder;
    return $Folder;
}

sub _createCustomerFolderWithoutCustomer {
    my $self = shift;
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
        'DE_EPAGES::Object::API::Object::Object',
        []
    );
    $Mockify->addMockWithReturnValueAndParameterCheck('existsChild', 0, ['string']);
    my $Folder = $Mockify->getMockObject();
    $self->{'Customer'} = $Folder;
    return $Folder;
}


__PACKAGE__->runScript();