#========================================================================================
# package      DE_EPAGES::DHLIntraship::t::unit::Builder
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for Builder.
#========================================================================================
package DE_EPAGES::DHLIntraship::t::unit::Builder;

use base DE_EPAGES::Core::API::Test;
use DE_EPAGES::DHLIntraship::API::SOAP::Builder;
use DE_EPAGES::Test::Mock::EpagesObject;
use DE_EPAGES::Test::Mock::Mockify;
use Test::Exception;
use Test::More;

use strict;

use constant CREATE_SHIPMENTDD => 'createShipmentDD';

sub test {
    my $self = shift;
    $self->_test_createShipmentDD_withoutPackstation_withCustomerCompany();
    $self->_test_createShipmentDD_withoutPackstation_GermanCustomerAddress();
    $self->_test_createShipmentDD_withoutPackstation_EnglishCustomerAddress();
    $self->_test_createShipmentDD_withoutPackstation_SpanishCustomerAddress();
    $self->_test_createShipmentDD_withPackstation();
    done_testing();
}

#----------------------------------------------------------------------------------------
# Tests
#----------------------------------------------------------------------------------------
sub _test_createShipmentDD_withoutPackstation_withCustomerCompany {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $ShippingAddressValues = {
        'City'            => 'Butzbach',
        'Company'         => 'Howarts',
        'Country'         => { 'Code2' => 'DE', },
        'HouseNumber'     => '9',
        'IsPickupAddress' => 0,
        'StreetOnly'      => 'Schorbachstrasse',
        'Zipcode'         => '35510',
        'Street2'         => 'c/o 123'
    };
    my $MockedShippingLabel = $self->_createShippingLabel($ShippingAddressValues);
    my $MockedBuilder       = $self->_createBuilder();
    my $hRequest            = $MockedBuilder->assemble( CREATE_SHIPMENTDD, $MockedShippingLabel );
    is_deeply(
        $hRequest,
        $self->_getExpectedRequest_WithoutPackstation_withCustomerCompany( $self->_getGermanCustomerAddress() ),
        "$SubTestName - Hash structure is correct."
    );

    return;
}

sub _test_createShipmentDD_withoutPackstation_GermanCustomerAddress {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $ShippingAddressValues = {
        'City'            => 'Butzbach',
        'Country'         => { 'Code2' => 'DE', },
        'HouseNumber'     => '9',
        'IsPickupAddress' => 0,
        'StreetOnly'      => 'Schorbachstrasse',
        'Zipcode'         => '35510',
        'Street2'         => 'c/o 123'
    };
    my $MockedShippingLabel = $self->_createShippingLabel($ShippingAddressValues);
    my $MockedBuilder       = $self->_createBuilder();
    my $hRequest            = $MockedBuilder->assemble( CREATE_SHIPMENTDD, $MockedShippingLabel );
    is_deeply( $hRequest, $self->_getExpectedRequest_WithoutPackstation( $self->_getGermanCustomerAddress() ), "$SubTestName - Hash structure is correct." );

    return;
}

sub _test_createShipmentDD_withoutPackstation_EnglishCustomerAddress {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $ShippingAddressValues = {
        'City'            => 'Oxford',
        'Country'         => { 'Code2' => 'UK', },
        'HouseNumber'     => '2',
        'IsPickupAddress' => 0,
        'StreetOnly'      => 'Endeavour House, Langford Business Park',
        'Zipcode'         => 'OX5 1GE',
        'Street2'         => 'c/o 123'
    };
    my $MockedShippingLabel = $self->_createShippingLabel($ShippingAddressValues);
    my $MockedBuilder       = $self->_createBuilder();
    my $hRequest            = $MockedBuilder->assemble( CREATE_SHIPMENTDD, $MockedShippingLabel );
    is_deeply( $hRequest, $self->_getExpectedRequest_WithoutPackstation( $self->_getEnglishCustomerAddress() ), "$SubTestName - Hash structure is correct." );

    return;
}

sub _test_createShipmentDD_withoutPackstation_SpanishCustomerAddress {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $ShippingAddressValues = {
        'City'            => 'Barcelona',
        'Country'         => { 'Code2' => 'ES', },
        'HouseNumber'     => '435',
        'IsPickupAddress' => 0,
        'StreetOnly'      => 'Avinguda Diagonal',
        'Zipcode'         => '08036',
        'Street2'         => 'c/o 123'
    };
    my $MockedShippingLabel = $self->_createShippingLabel($ShippingAddressValues);
    my $MockedBuilder       = $self->_createBuilder();
    my $hRequest            = $MockedBuilder->assemble( CREATE_SHIPMENTDD, $MockedShippingLabel );
    is_deeply( $hRequest, $self->_getExpectedRequest_WithoutPackstation( $self->_getSpanishCustomerAddress() ), "$SubTestName - Hash structure is correct." );

    return;
}

sub _test_createShipmentDD_withPackstation {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $ShippingAddressValues = {
        'City'            => 'Butzbach',
        'Country'         => { 'Code2' => 'DE', },
        'HouseNumber'     => '9',
        'IsPickupAddress' => 1,
        'StreetOnly'      => 'Schorbachstrasse',
        'Zipcode'         => '35510',
    };
    my $MockedShippingLabel = $self->_createShippingLabel($ShippingAddressValues);
    my $MockedBuilder       = $self->_createBuilder();
    my $hRequest            = $MockedBuilder->assemble( CREATE_SHIPMENTDD, $MockedShippingLabel );
    is_deeply( $hRequest, $self->_getExpectedRequest_WithPackstation(), "$SubTestName - Hash structure is correct." );

    return;
}

#----------------------------------------------------------------------------------------
# Requests
#----------------------------------------------------------------------------------------
## no critic (ProhibitFunctionSize)
sub _getExpectedRequest_WithoutPackstation {
    my $self = shift;
    my ($CustomerAddress) = @_;

    return {
        'Version' => {
            'minorRelease' => 0,
            'majorRelease' => 1,
            'build'        => 14
        },
        'ShipmentOrder' => {
            'Shipment' => {
                'ShipmentDetails' => {
                    'Attendance'   => { 'partnerID' => '01' },
                    'Notification' => [ {
                            'RecipientName'         => 'RecipientLastName',
                            'RecipientEmailAddress' => 'RecipientEmail'
                        }
                    ],
                    'EKP'                          => '5000000008',
                    'ProductCode'                  => 'BPI',
                    'ShipmentDate'                 => 'Nov 10, 2015 12:00:00 AM',
                    'DeclaredValueOfGoods'         => 72.95,
                    'DeclaredValueOfGoodsCurrency' => 'EUR',
                    ,
                    'CustomerReference' => '1008-3',
                    'ShipmentItem'      => {
                        'WeightInKG'   => 10,
                        'ParcelWidth'  => '0',
                        'ParcelLength' => '0',
                        'PackageType'  => 'PK',
                        'ParcelDepth'  => '0'
                    }
                },
                'Shipper' => {
                    'Communication' => {
                        'email'         => 'ShipperEmail',
                        'mobile'        => '666666661',
                        'phone'         => '666666666',
                        'contactPerson' => 'ShipperFullName'
                    },
                    'Address' => {
                        'city'         => 'Hamburg',
                        'streetNumber' => '2',
                        'Origin'       => { 'countryISOCode' => 'DE' },
                        'Zip'          => { 'germany' => '20355' },
                        'streetName'   => 'Pilatuspool',
                        'careOfName'   => 'c/o 123'
                    },
                    'Company' => { 'Company' => { 'name1' => 'Xavizon', }, }
                },
                'Receiver' => {
                    'Communication' => {
                        'email'  => 'RecipientEmail',
                        'mobile' => '777777771',
                        'phone'  => '777777777',
                    },
                    'Address' => $CustomerAddress,
                    'Company' => { 'Company' => { 'name1' => 'RecipientFullName', }, }
                }
            },
            'SequenceNumber' => '18370'
        },
        'header' => {
            'signature' => 'TomRiddle',
            'user'      => 'LordXavimort',
            'type'      => '0'
        }
    };
}

#----------------------------------------------------------------------------------------
sub _getExpectedRequest_WithPackstation {
    my $self = shift;

    return {
        'Version' => {
            'minorRelease' => 0,
            'majorRelease' => 1,
            'build'        => 14
        },
        'ShipmentOrder' => {
            'Shipment' => {
                'ShipmentDetails' => {
                    'Attendance'   => { 'partnerID' => '01' },
                    'Notification' => [ {
                            'RecipientName'         => 'RecipientLastName',
                            'RecipientEmailAddress' => 'RecipientEmail'
                        }
                    ],
                    'EKP'                          => '5000000008',
                    'ProductCode'                  => 'BPI',
                    'ShipmentDate'                 => 'Nov 10, 2015 12:00:00 AM',
                    'DeclaredValueOfGoods'         => 72.95,
                    'DeclaredValueOfGoodsCurrency' => 'EUR',
                    ,
                    'CustomerReference' => '1008-3',
                    'ShipmentItem'      => {
                        'WeightInKG'   => 10,
                        'ParcelWidth'  => '0',
                        'ParcelLength' => '0',
                        'PackageType'  => 'PK',
                        'ParcelDepth'  => '0'
                    }
                },
                'Shipper' => {
                    'Communication' => {
                        'email'         => 'ShipperEmail',
                        'mobile'        => '666666661',
                        'phone'         => '666666666',
                        'contactPerson' => 'ShipperFullName'
                    },
                    'Address' => {
                        'city'         => 'Hamburg',
                        'streetNumber' => '2',
                        'Origin'       => { 'countryISOCode' => 'DE' },
                        'Zip'          => { 'germany' => '20355' },
                        'streetName'   => 'Pilatuspool',
                        'careOfName'   => 'c/o 123'
                    },
                    'Company' => { 'Company' => { 'name1' => 'Xavizon', }, }
                },
                'Receiver' => {
                    'Communication' => {
                        'email'  => 'RecipientEmail',
                        'mobile' => '777777771',
                        'phone'  => '777777777',
                    },
                    'Packstation' => {
                        'PackstationNumber' => '140',
                        'PostNumber'        => '0123456789',
                        'Zip'               => '35510',
                        'City'              => 'Butzbach',
                    },
                    'Company' => {
                        'Company' => {
                            'name1' => undef,
                            'name2' => '0123456789',

                        },
                    }
                }
            },
            'SequenceNumber' => '18370'
        },
        'header' => {
            'signature' => 'TomRiddle',
            'user'      => 'LordXavimort',
            'type'      => '0'
        }
    };
}

#----------------------------------------------------------------------------------------
sub _getExpectedRequest_WithoutPackstation_withCustomerCompany {
    my $self = shift;
    my ($CustomerAddress) = @_;

    return {
        'Version' => {
            'minorRelease' => 0,
            'majorRelease' => 1,
            'build'        => 14
        },
        'ShipmentOrder' => {
            'Shipment' => {
                'ShipmentDetails' => {
                    'Attendance'   => { 'partnerID' => '01' },
                    'Notification' => [ {
                            'RecipientName'         => 'RecipientLastName',
                            'RecipientEmailAddress' => 'RecipientEmail'
                        }
                    ],
                    'EKP'                          => '5000000008',
                    'ProductCode'                  => 'BPI',
                    'ShipmentDate'                 => 'Nov 10, 2015 12:00:00 AM',
                    'DeclaredValueOfGoods'         => 72.95,
                    'DeclaredValueOfGoodsCurrency' => 'EUR',
                    ,
                    'CustomerReference' => '1008-3',
                    'ShipmentItem'      => {
                        'WeightInKG'   => 10,
                        'ParcelWidth'  => '0',
                        'ParcelLength' => '0',
                        'PackageType'  => 'PK',
                        'ParcelDepth'  => '0'
                    }
                },
                'Shipper' => {
                    'Communication' => {
                        'email'         => 'ShipperEmail',
                        'mobile'        => '666666661',
                        'phone'         => '666666666',
                        'contactPerson' => 'ShipperFullName'
                    },
                    'Address' => {
                        'city'         => 'Hamburg',
                        'streetNumber' => '2',
                        'Origin'       => { 'countryISOCode' => 'DE' },
                        'Zip'          => { 'germany' => '20355' },
                        'streetName'   => 'Pilatuspool',
                        'careOfName'   => 'c/o 123'
                    },
                    'Company' => { 'Company' => { 'name1' => 'Xavizon', }, }
                },
                'Receiver' => {
                    'Communication' => {
                        'email'  => 'RecipientEmail',
                        'mobile' => '777777771',
                        'phone'  => '777777777',
                    },
                    'Address' => $CustomerAddress,
                    'Company' => { 'Company' => { 'name1' => 'Howarts', 'name2' => 'RecipientFullName' }, }
                }
            },
            'SequenceNumber' => '18370'
        },
        'header' => {
            'signature' => 'TomRiddle',
            'user'      => 'LordXavimort',
            'type'      => '0'
        }
    };
}

## use critic (ProhibitFunctionSize)

sub _getEnglishCustomerAddress {
    my $self = shift;
    return {
        'city'         => 'Oxford',
        'streetNumber' => '2',
        'Origin'       => { 'countryISOCode' => 'UK' },
        'Zip'          => { 'england' => 'OX5 1GE' },
        'streetName'   => 'Endeavour House, Langford Business Park',
        'careOfName'   => 'c/o 123'
    };
}

sub _getGermanCustomerAddress {
    my $self = shift;
    return {
        'city'         => 'Butzbach',
        'streetNumber' => '9',
        'Origin'       => { 'countryISOCode' => 'DE' },
        'Zip'          => { 'germany' => '35510' },
        'streetName'   => 'Schorbachstrasse',
        'careOfName'   => 'c/o 123'
    };
}

sub _getSpanishCustomerAddress {
    my $self = shift;
    return {
        'city'         => 'Barcelona',
        'streetNumber' => '435',
        'Origin'       => { 'countryISOCode' => 'ES' },
        'Zip'          => { 'other' => '08036' },
        'streetName'   => 'Avinguda Diagonal',
        'careOfName'   => 'c/o 123'
    };
}

#----------------------------------------------------------------------------------------
# Helpers
#----------------------------------------------------------------------------------------
sub _createBuilder {
    my $self = shift;

    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::DHLIntraship::API::SOAP::Builder');

    $Mockify->addMock(
        '_getShippingLabelInfo',
        sub {
            shift;
            my ($MockedShippingLabel) = @_;

            return $self->_createShippingLabelInfo($MockedShippingLabel);
        }
    );

    $Mockify->addMock(
        '_getShopAddressInfo',
        sub {
            shift;
            my ($MockedShippingLabel) = @_;

            return $self->_createShopAddressInfo($MockedShippingLabel);
        }
    );

    $Mockify->addMock(
        '_getCustomerAddressInfo',
        sub {
            shift;
            my ($MockedShippingLabel) = @_;

            return $self->_createCustomerAddressInfo($MockedShippingLabel);
        }
    );

    $Mockify->addMock(
        '_getProductsInfo',
        sub {
            shift;
            my ($MockedShippingLabel) = @_;

            return $self->_createProductsInfo($MockedShippingLabel);
        }
    );

    return $Mockify->getMockObject();
}

#----------------------------------------------------------------------------------------
sub _createCustomerAddressInfo {
    my $self = shift;
    my ($MockedShippingLabel) = @_;

    my $MockedCustomerAddressInfo = DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::DHLIntraship::API::ShippingLabelAttributes::CustomerAddress');
    my $MockedAddress             = $MockedShippingLabel->get('Address');
    $MockedCustomerAddressInfo->{'City'}             = $MockedAddress->get('City');
    $MockedCustomerAddressInfo->{'Code2'}            = $MockedAddress->get('Country')->{'Code2'};
    $MockedCustomerAddressInfo->{'Company'}          = $MockedAddress->get('Company');
    $MockedCustomerAddressInfo->{'DHLPackstationId'} = $MockedAddress->get('DHLPackstationId');
    $MockedCustomerAddressInfo->{'DHLPostNumber'}    = $MockedAddress->get('DHLPostNumber');
    $MockedCustomerAddressInfo->{'EMail'}            = $MockedAddress->get('EMail');
    $MockedCustomerAddressInfo->{'FullName'}         = $MockedAddress->get('FullName');
    $MockedCustomerAddressInfo->{'HouseNumber'}      = $MockedAddress->get('HouseNumber');
    $MockedCustomerAddressInfo->{'IsPickupAddress'}  = $MockedAddress->get('IsPickupAddress');
    $MockedCustomerAddressInfo->{'LastName'}         = $MockedAddress->get('LastName');
    $MockedCustomerAddressInfo->{'Phone'}            = $MockedAddress->get('Phone');
    $MockedCustomerAddressInfo->{'PhoneCell'}        = $MockedAddress->get('PhoneCell');
    $MockedCustomerAddressInfo->{'StreetOnly'}       = $MockedAddress->get('StreetOnly');
    $MockedCustomerAddressInfo->{'Zipcode'}          = $MockedAddress->get('Zipcode');
    $MockedCustomerAddressInfo->{'Street2'}          = $MockedAddress->get('Street2');

    return $MockedCustomerAddressInfo;
}

#----------------------------------------------------------------------------------------
sub _createLineItemContainer {
    my $self = shift;

    my $hAttributes = { 'LineItemsSum' => 72.95, };
    my $LineItemContainer = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Order::API::Object::LineItemContainer', $hAttributes );

    return $LineItemContainer;
}

#----------------------------------------------------------------------------------------
sub _createProductsInfo {
    my $self = shift;
    my ($MockedShippingLabel) = @_;

    my $MockedProductsInfo      = DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::DHLIntraship::API::ShippingLabelAttributes::Products');
    my $MockedLineItemContainer = $MockedShippingLabel->get('LineItemContainer');
    $MockedProductsInfo->{'LineItemsSum'} = $MockedLineItemContainer->get('LineItemsSum');
    $MockedProductsInfo->{'TotalWeight'}  = $MockedShippingLabel->get('TotalWeight');
    $MockedProductsInfo->{'ParcelWidth'}  = $MockedShippingLabel->get('ParcelWidth');
    $MockedProductsInfo->{'ParcelLength'} = $MockedShippingLabel->get('ParcelLength');
    $MockedProductsInfo->{'ParcelDepth'}  = $MockedShippingLabel->get('ParcelDepth');

    return $MockedProductsInfo;
}

#----------------------------------------------------------------------------------------
sub _createShippingAddress {
    my $self = shift;
    my ($ShippingAddressValues) = @_;

    my $hAttributes = {
        'City'             => $ShippingAddressValues->{'City'},
        'Company'          => $ShippingAddressValues->{'Company'},
        'Country'          => $ShippingAddressValues->{'Country'},
        'DHLPackstationId' => '140',
        'DHLPostNumber'    => '0123456789',
        'EMail'            => 'RecipientEmail',
        'FullName'         => 'RecipientFullName',
        'HouseNumber'      => $ShippingAddressValues->{'HouseNumber'},
        'IsPickupAddress'  => $ShippingAddressValues->{'IsPickupAddress'},
        'LastName'         => 'RecipientLastName',
        'Phone'            => '777777777',
        'PhoneCell'        => '777777771',
        'StreetOnly'       => $ShippingAddressValues->{'StreetOnly'},
        'Zipcode'          => $ShippingAddressValues->{'Zipcode'},
        'Street2'          => $ShippingAddressValues->{'Street2'}
    };
    my $Address = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Address::API::Object::Address', $hAttributes );

    return $Address;
}

#----------------------------------------------------------------------------------------
sub _createShippingFulfillmentMethodDHLIntraship {
    my $self = shift;

    my $hAttributes = {
        'CustomerNumber'     => '50000000087201',
        'WebserviceUsername' => 'LordXavimort',
        'WebservicePassword' => 'TomRiddle'
    };
    my $MockedShippingFulfillmentMethodDHLIntraship
      = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::DHLIntraship::API::Object::ShippingFulfillmentMethodDHLIntraship', $hAttributes );

    return $MockedShippingFulfillmentMethodDHLIntraship;
}

#----------------------------------------------------------------------------------------
sub _createShippingLabel {
    my $self = shift;
    my ($ShippingAddressValues) = @_;

    my $hAttributes = {
        'Address'                   => $self->_createShippingAddress($ShippingAddressValues),
        'Alias'                     => '1008-3',
        'EstimatedDeliveryDate'     => 'Nov 10, 2015 12:00:00 AM',
        'ID'                        => '18370',
        'LineItemContainer'         => $self->_createLineItemContainer(),
        'ParcelDepth'               => 0,
        'ParcelLength'              => 0,
        'ParcelWidth'               => 0,
        'ShippingFulfillmentMethod' => $self->_createShippingFulfillmentMethodDHLIntraship(),
        'ShopAddress'               => $self->_createShopAddress(),
        'TotalWeight'               => 10,
    };
    my $ShippingLabel = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::DHLIntraship::API::Object::ShippingLabelDHLIntraship', $hAttributes );

    return $ShippingLabel;
}

#----------------------------------------------------------------------------------------
sub _createShippingLabelInfo {
    my $self = shift;
    my ($MockedShippingLabel) = @_;

    my $hAttributes = { 'ShippingLabel' => $MockedShippingLabel, };
    my $MockedShippingLabelInfo
      = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::DHLIntraship::API::ShippingLabelAttributes::ShippingLabel', $hAttributes );
    $MockedShippingLabelInfo->{'ShippingFulfillmentMethod'} = $MockedShippingLabel->get('ShippingFulfillmentMethod');
    $MockedShippingLabelInfo->{'Alias'}                     = $MockedShippingLabel->get('Alias');
    $MockedShippingLabelInfo->{'ProductCode'}               = 'BPI';
    $MockedShippingLabelInfo->{'EstimatedDeliveryDate'}     = $MockedShippingLabel->get('EstimatedDeliveryDate');

    return $MockedShippingLabelInfo;
}

#----------------------------------------------------------------------------------------
sub _createShopAddress {
    my $self = shift;

    my $hAttributes = {
        'City'            => 'Hamburg',
        'Country'         => { 'Code2' => 'DE', },
        'Company'         => 'Xavizon',
        'EMail'           => 'ShipperEmail',
        'FullName'        => 'ShipperFullName',
        'HouseNumber'     => '2',
        'IsPickupAddress' => 0,
        'Phone'           => '666666666',
        'PhoneCell'       => '666666661',
        'StreetOnly'      => 'Pilatuspool',
        'Zipcode'         => '20355',
        'Street2'         => 'c/o 123'
    };
    my $ShopAddress = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Address::API::Object::Address', $hAttributes );

    return $ShopAddress;
}

#----------------------------------------------------------------------------------------
sub _createShopAddressInfo {
    my $self = shift;
    my ($MockedShippingLabel) = @_;

    my $MockedShopAddressInfo = DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::DHLIntraship::API::ShippingLabelAttributes::ShopAddress');
    my $MockedAddress         = $MockedShippingLabel->get('ShopAddress');
    $MockedShopAddressInfo->{'City'}            = $MockedAddress->get('City');
    $MockedShopAddressInfo->{'Code2'}           = $MockedAddress->get('Country')->{'Code2'};
    $MockedShopAddressInfo->{'Company'}         = $MockedAddress->get('Company');
    $MockedShopAddressInfo->{'EMail'}           = $MockedAddress->get('EMail');
    $MockedShopAddressInfo->{'FullName'}        = $MockedAddress->get('FullName');
    $MockedShopAddressInfo->{'HouseNumber'}     = $MockedAddress->get('HouseNumber');
    $MockedShopAddressInfo->{'IsPickupAddress'} = $MockedAddress->get('IsPickupAddress');
    $MockedShopAddressInfo->{'Phone'}           = $MockedAddress->get('Phone');
    $MockedShopAddressInfo->{'PhoneCell'}       = $MockedAddress->get('PhoneCell');
    $MockedShopAddressInfo->{'StreetOnly'}      = $MockedAddress->get('StreetOnly');
    $MockedShopAddressInfo->{'Zipcode'}         = $MockedAddress->get('Zipcode');
    $MockedShopAddressInfo->{'Street2'}         = $MockedAddress->get('Street2');

    return $MockedShopAddressInfo;
}

__PACKAGE__->runScript();

1;

