/*
 * Copyright (c) 2006-2007, ePages GmbH
 * All Rights Reserved.
 *
 * epages.templated.js
 */

dojo.provide('epages.templated');

dojo.require('dijit._Templated');
dojo.require('epages.io.translation');

(function(dj){

	dj.declare('epages.Templated',null,{
	
		_translator: 			new epages.io.Translation(),	// translation handler
		_templatesCache:		null,							// hash of cached templates
		templates:				null,							// hash of templates
		
		constructor: function() {
			this.templates = 		this.templates		|| {};
			this._templatesCache = 	this._templatesCache|| {};
		},
		
		loadLocale: function( /*string*/url, /*string|boolean?*/locale ) {
			// summary: load translation data
				// url: 					src url of the dictionary file (without locale and extension ".xml")
				// locale: 		[string]	(RFC 3066; eg en-us) 
				//				[boolean] 	locale=default and set skipError
				//				[?] 		locale=default and skipError=false
			var type = typeof locale;
			if( type==='boolean' ) {
				this._translator.load( url, locale );
			}
			else if( type==='string' ) {
				this._translator.loadLocale( url, locale );
			}
		},
		
		loadTemplate: function( /*string*/url, /*string*/name ) {
			// summary: load template file
				// url: 					moduleUrl of the template file
				// name: 					name to store the template
			this.templates[name] = dijit._Templated.getCachedTemplate( url, null, false );
		},
		
		addTemplate: function( /*string*/template, /*string*/name ) {
			// summary: load template file
				// template: 				string of the template
				// name: 					name to store the template
			this.templates[name] = template;
		},
		
		getTemplate: function( /*string*/name, /*boolean*/noCache ) {
			// summary: get a localized template as domNode with attachpoints
				// name: 					name of the stored template
				// noCache: 				true = new translate and trim
			if( this.templates[name] ) {
				if( !this._templatesCache[name] || !noCache ) {
					this._templatesCache[name] = this._translator.replaceLanguageTags( this.templates[name].replace(/[\ \r\n\t]*(.*)[\ \r\n\t]*/,function(string,$1){return $1;}) );
				}
				
				var container = document.createElement('div');
					container.innerHTML = this._templatesCache[name];
					
				var ret = {};
				
				var widgets = dojo.parser.parse(container);
				
				for( var i=0,iLength=widgets.length ; i<iLength ; i++ ) {
					ret[widgets[i].id] = widgets[i].domNode;
				}
				
				ret.domNode = container.childNodes[0];
				
				dj.query('*[dojoAttachpoint]',container).forEach(function(node,i){
					ret[dj.attr(node,'dojoAttachpoint')] = node;
					dj.removeAttr( node, 'dojoAttachpoint' );
				});
				
				
				return this._templatesCache[name] = ret;
			}
		}
	
	});

})(dojo);
