#========================================================================================
# package      DE_EPAGES::Order::t::unit::OrderResource
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::Order::API::Resource::OrderResource
#========================================================================================
package DE_EPAGES::Order::t::unit::OrderResource;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::Mockify;
use DE_EPAGES::Test::Mock::Mockery;
use Test::More;

use strict;



sub test {
    my $self = shift;

    $self->test_get();
    $self->test_get_withoutLocale();

    $self->test_put();

    done_testing();
}



sub test_get {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $OrderResource = $Mockery->get('SUT');
    my $Order = $Mockery->get('order');

    my $hOrderData = $OrderResource->get($Order, 'en_GB');

    is_deeply($hOrderData, $self->_createOrderData(), "$SubTestName - test if expected order data was returned");
}



sub test_get_withoutLocale {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $OrderResource = $Mockery->get('SUT');
    my $Order = $Mockery->get('order');

    my $hOrderData = $OrderResource->get($Order);

    is_deeply($hOrderData, $self->_createOrderData(), "$SubTestName - test if expected order data was returned");
}



sub test_put {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $OrderResource = $Mockery->get('SUT');
    my $Order = $Mockery->get('order');

    my $hOrderData = {
        'comment' => 'TestComment',
    };

    $OrderResource->put($Order, $hOrderData);

    is($Order->get('Comment'), 'TestComment', "$SubTestName - test if order comment was changed.");
}



sub _createMocks {
    my $self = shift;

    my $Mockery = DE_EPAGES::Test::Mock::Mockery->new();

    $Mockery->register('SUT', ['OrderService'], sub {
        my ($OrderService) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Order::API::Resource::OrderResource', []);
        $Mockify->addMockWithReturnValue('_createOrderService', $OrderService);
        $Mockify->addMockWithReturnValue('_createSoapOrderService', undef);
        return $Mockify->getMockObject();
    });
    $Mockery->register('Order', ['Shop'], sub {
        my ($Shop) = @_;
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Order::API::Object::CustomerOrder', {
            'Alias' => 'TestObject',
            'Site' => $Shop,
        });
        return $MockifyEpagesObject->getMockObject();
    });
    $Mockery->register('Shop', [], sub {
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', {
            'Alias' => 'TestShop',
            'LocaleID' => 'de_DE',
        });
        $MockifyEpagesObject->addMockWithReturnValueAndParameterCheck('existsSiteLocale', 1, [{'string' => 'en_GB'}]);
        return $MockifyEpagesObject->getMockObject();
    });
    $Mockery->register('OrderService', [], sub {
        my ($OrderService) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Order::API::OrderService', []);
        $Mockify->addMockWithReturnValueAndParameterCheck('getOrderDataWithLineItemContainer', $self->_createOrderData(), ['object', 'string']);
        return $Mockify->getMockObject();
    });

    return $Mockery->assemble();
}



sub _createOrderData {
    return {
        'guid' => '12345',
    }
}

__PACKAGE__->runScript();