#========================================================================================
# package      DE_EPAGES::Order::t::unit::OrderService
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::Order::API::OrderService
#========================================================================================
package DE_EPAGES::Order::t::unit::OrderService;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::Mockify;
use DE_EPAGES::Test::Mock::Mockery;
use Test::More;
use DateTime;

use strict;

## no critic (ProhibitLongLines)



sub test {
    my $self = shift;

    $self->test_getOrderData();
    $self->test_getOrderDataWithLineItemContainer();

    done_testing();
}



sub test_getOrderData {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $OrderService = $Mockery->get('SUT');
    my $Order = $Mockery->get('Order');

    my $hOrderData = $OrderService->getOrderData($Order, 'gb_GB');

    my $hExpectedData = $self->_createExpectedOrderData();
    is_deeply($hOrderData, $hExpectedData, "$SubTestName - test if correct order data was returned.");
}



sub test_getOrderDataWithLineItemContainer {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $OrderService = $Mockery->get('SUT');
    my $Order = $Mockery->get('Order');

    my $hOrderData = $OrderService->getOrderDataWithLineItemContainer($Order, 'gb_GB');

    my $hExpectedData = $self->_createExpectedOrderDataWithLineItemContainer();
    is_deeply($hOrderData, $hExpectedData, "$SubTestName - test if correct order data was returned.");
}



sub _createMocks {
    my $self = shift;

    my $Mockery = DE_EPAGES::Test::Mock::Mockery->new();

    $Mockery->register('SUT', ['Locale', 'LineItemContainerData'], sub {
        my ($Locale, $LineItemContainerData) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Order::API::OrderService', []);
        $Mockify->addMockWithReturnValueAndParameterCheck('_loadLocaleById', $Locale, ['string']);
        $Mockify->addMockWithReturnValueAndParameterCheck('_createLineItemContainerData', $LineItemContainerData, ['object']);
        return $Mockify->getMockObject();
    });
    ## no critic (ProhibitMagicNumbers)
    $Mockery->register('Order', ['Shop', 'Customer', 'LineItemContainer'], sub {
        my ($Shop, $Customer, $LineItemContainer) = @_;
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Order::API::Object::CustomerOrder', {
            'Alias' => 'TestObject',
            'Site' => $Shop,
            'GUID' => '1234-5678-910',
            'BillingAddress' => '',
            'ShippingAddress' => '',
            'Customer' => $Customer,
            'Comment' => 'TestComment',
            'CustomerComment' => 'TestCustomerComment',
            'User' => undef,
            'LineItemContainer' => $LineItemContainer,
            'CreationDate' => $self->_createDateTime(11, 45),
            'DispatchedOn' => $self->_createDateTime(12, 44),
            'ArchivedOn' => $self->_createDateTime(13, 43),
            'CancelledOn' => $self->_createDateTime(14, 42),
            'ClosedOn' => $self->_createDateTime(15, 41),
            'PaidOn' => $self->_createDateTime(16, 40),
            'ReturnedOn' => $self->_createDateTime(17, 39),
            'ViewedOn' => $self->_createDateTime(18, 38),
            'PendingOn' => $self->_createDateTime(19, 37),
            'ShippedOn' => $self->_createDateTime(20, 36),
            'InvoicedOn' => $self->_createDateTime(21, 35),
            'ReadyForShippingOn' => $self->_createDateTime(21, 35),
            'InProcessOn' => $self->_createDateTime(21, 35),
            'PartlyDispatchedOn' => $self->_createDateTime(21, 35),
            'PartlyInvoicedOn' => $self->_createDateTime(21, 35),
            'PartlyPaidOn' => $self->_createDateTime(21, 35),
        });
        return $MockifyEpagesObject->getMockObject();
    });
    ## use critic (ProhibitMagicNumbers)
    $Mockery->register('Shop', [], sub {
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', {
            'Alias' => 'TestShop',
            'LocaleID' => 'de_DE',
        });
        $MockifyEpagesObject->addMockWithReturnValueAndParameterCheck('existsSiteLocale', 1, [{'string' => 'en_GB'}]);
        return $MockifyEpagesObject->getMockObject();
    });
    $Mockery->register('Customer', [], sub {
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Customer::API::Object::Customer', {
            'GUID' => '4535-24535443-2343',
            'Alias' => '1007',
        });
        return $MockifyEpagesObject->getMockObject();
    });
    $Mockery->register('Locale', [], sub {
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Object::API::Object::Locale', {
            'Alias' => 'TestLocale',
            'LanguageID' => 123,
        });
        return $MockifyEpagesObject->getMockObject();
    });
    $Mockery->register('LineItemContainer', [], sub {
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Order::API::Object::LineItemContainer', {
            'Alias' => 'TestLineItemContainer',
            'CurrencyID' => 'EUR',
            'TaxModel' => 'GROSS',
            'GrandTotal' => '123.45',
            'TotalBeforeTax' => '56',
            'TotalTax' => '23',
        });
        return $MockifyEpagesObject->getMockObject();
    });
    $Mockery->register('LineItemContainerData', ['Order'], sub {
        my ($Order) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Order::API::LineItemContainerData', [$Order]);
        $Mockify->addMockWithReturnValueAndParameterCheck('getLineItemContainerData', 'lineItemContainerData', ['string', 'string']);
        $Mockify->addMockWithReturnValueAndParameterCheck('getShippingData', 'shippingData', ['string', 'string']);
        $Mockify->addMockWithReturnValueAndParameterCheck('getPaymentData', 'paymentData', ['string', 'string']);
        return $Mockify->getMockObject();
    });

    return $Mockery->assemble();
}



sub _createDateTime {
    my $self = shift;
    my ($Hour, $Minute) = @_;
    my $DateTime = DateTime->new(
        year       => 2015,
        month      => 4,
        day        => 21,
        hour       => $Hour,
        minute     => $Minute,
        second     => 3,
        nanosecond => 0,
        time_zone  => 'Europe/Berlin',
    );
    return $DateTime;
}



sub _createExpectedOrderDataWithLineItemContainer {
    my $self = shift;
    my $hOrderData = $self->_createExpectedOrderData();
    $hOrderData->{'lineItemContainer'} = 'lineItemContainerData';
    return $hOrderData;
}



sub _createExpectedOrderData {
    return {
      'paidOn' => '2015-04-21T14:40:03Z',
      'paymentData' => 'paymentData',
      'currencyId' => 'EUR',
      'orderId' => '1234-5678-910',
      'taxModel' => 'NET',
      'orderNumber' => 'TestObject',
      'cancelledOn' => '2015-04-21T12:42:03Z',
      'shippingData' => 'shippingData',
      'viewedOn' => '2015-04-21T16:38:03Z',
      'invoicedOn' => '2015-04-21T19:35:03Z',
      'shippingAddress' => undef,
      'dispatchedOn' => '2015-04-21T10:44:03Z',
      'returnedOn' => '2015-04-21T15:39:03Z',
      'closedOn' => '2015-04-21T13:41:03Z',
      'grandTotal' => '123.45',
      'archivedOn' => '2015-04-21T11:43:03Z',
      'totalBeforeTax' => '56',
      'customerId' => '4535-24535443-2343',
      'customerNumber' => '1007',
      'totalTax' => '23',
      'creationDate' => '2015-04-21T09:45:03Z',
      'pendingOn' => '2015-04-21T17:37:03Z',
      'customerComment' => 'TestCustomerComment',
      'internalNote' => 'TestComment',
      'billingAddress' => undef,
      'shippedOn' => '2015-04-21T18:36:03Z',
      'inProcessOn' => '2015-04-21T19:35:03Z',
      'readyForShippingOn' => '2015-04-21T19:35:03Z',
      'partlyDispatchedOn' => '2015-04-21T19:35:03Z',
      'partlyInvoicedOn' => '2015-04-21T19:35:03Z',
      'partlyPaidOn' => '2015-04-21T19:35:03Z'
    };
}

__PACKAGE__->runScript();