package DE_EPAGES::PayPalExpress::t::unit::HooksLineItemContainer;
use base DE_EPAGES::Core::API::Test;
use Test::More;
use strict;

use DE_EPAGES::PayPalExpress::Hooks::LineItemContainer;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;

sub test {
    my $self = shift;
    $self->test_PPE_OnlyPayment();
    $self->test_PPE_WithOnlyAmazonPayments();
    $self->test_PPE_CorrectViewAction_DefaultPayment();
    $self->test_PPE_CorrectViewAction_NotDefaultPayment();
    $self->test_PPE_WrongViewAction();
    $self->test_PPE_HideExpressButton();
    $self->test_PPE_DontHide();
    done_testing();
}

sub test_PPE_OnlyPayment {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $aPaymentMethods = ();
    my $Paymentmethod1 = $self->_createPaymentMethod('DE_EPAGES::PayPalExpress::API::Object::PaymentMethodPayPalExpress', {
        'instanceOf' => 'PaymentMethodPayPalExpress',
        'IsDefault' => 1,
        'HidePayPalExpress' => 0,
        'HideInNormalCheckout' => 1,
    });
    push(@$aPaymentMethods, $Paymentmethod1);

    my $hParams = {
        'LineItemContainer' => $self->_createLineItemContainer('ViewMultiCheckoutPayment'),
        'PaymentMethods' => $aPaymentMethods
    };

    DE_EPAGES::PayPalExpress::Hooks::LineItemContainer::OnLineItemContainerPaymentMethods($hParams);

    my $NumPayments = scalar(@$aPaymentMethods);
    is($NumPayments,1,"$SubTestName - Test if PayPalExpress was not deleted in this case");
}

sub test_PPE_WithOnlyAmazonPayments {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $aPaymentMethods = ();
    my $PaymentMethodPayPalExpress = $self->_createPaymentMethod('DE_EPAGES::PayPalExpress::API::Object::PaymentMethodPayPalExpress', {
        'instanceOf' => 'PaymentMethodPayPalExpress',
        'IsDefault' => 0,
        'HidePayPalExpress' => 0,
        'HideInNormalCheckout' => 1,
    });
    push(@$aPaymentMethods, $PaymentMethodPayPalExpress);

    my $PaymentMethodAmazonPayments = $self->_createPaymentMethod('DE_EPAGES::AmazonPayments::API::Object::PaymentMethodAmazonPayments', {
        'instanceOf' => 'PaymentMethodAmazonPayments',
        'IsDefault' => 1,
    });
    push(@$aPaymentMethods, $PaymentMethodAmazonPayments);

    my $hParams = {
        'LineItemContainer' => $self->_createLineItemContainer('ViewMultiCheckoutPayment'),
        'PaymentMethods' => $aPaymentMethods
    };

    DE_EPAGES::PayPalExpress::Hooks::LineItemContainer::OnLineItemContainerPaymentMethods($hParams);

    my $NumPayments = scalar(@$aPaymentMethods);
    is($NumPayments,2,"$SubTestName - Test if PayPalExpress was not deleted in this case");
}

sub test_PPE_CorrectViewAction_DefaultPayment {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $aPaymentMethods = ();
    my $PaymentMethodPayPalExpress = $self->_createPaymentMethod('DE_EPAGES::PayPalExpress::API::Object::PaymentMethodPayPalExpress', {
        'instanceOf' => 'PaymentMethodPayPalExpress',
        'IsDefault' => 1,
        'HidePayPalExpress' => 0,
        'HideInNormalCheckout' => 1,
    });
    push(@$aPaymentMethods, $PaymentMethodPayPalExpress);

    my $PaymentMethod = $self->_createPaymentMethod('DE_EPAGES::Payment::API::Object::PaymentMethod', {
        'instanceOf' => 'PaymentMethod',
        'IsDefault' => 0,
    });
    push(@$aPaymentMethods, $PaymentMethod);

    my $hParams = {
        'LineItemContainer' => $self->_createLineItemContainer('ViewMultiCheckoutPayment'),
        'PaymentMethods' => $aPaymentMethods
    };

    DE_EPAGES::PayPalExpress::Hooks::LineItemContainer::OnLineItemContainerPaymentMethods($hParams);

    my $NumPayments = scalar(@$aPaymentMethods);
    is($NumPayments,2,"$SubTestName - Test if PayPalExpress was not deleted in this case");
}

sub test_PPE_CorrectViewAction_NotDefaultPayment {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $aPaymentMethods = ();
    my $PaymentMethodPayPalExpress = $self->_createPaymentMethod('DE_EPAGES::PayPalExpress::API::Object::PaymentMethodPayPalExpress', {
        'instanceOf' => 'PaymentMethodPayPalExpress',
        'IsDefault' => 0,
        'HidePayPalExpress' => 0,
        'HideInNormalCheckout' => 1,
    });
    push(@$aPaymentMethods, $PaymentMethodPayPalExpress);

    my $PaymentMethod = $self->_createPaymentMethod('DE_EPAGES::Payment::API::Object::PaymentMethod', {
        'instanceOf' => 'PaymentMethod',
        'IsDefault' => 1,
    });
    push(@$aPaymentMethods, $PaymentMethod);

    my $hParams = {
        'LineItemContainer' => $self->_createLineItemContainer('ViewMultiCheckoutPayment'),
        'PaymentMethods' => $aPaymentMethods
    };

    DE_EPAGES::PayPalExpress::Hooks::LineItemContainer::OnLineItemContainerPaymentMethods($hParams);

    my $NumPayments = scalar(@$aPaymentMethods);
    is($NumPayments,1,"$SubTestName - Test if PayPalExpress was deleted in this case");
    ok($aPaymentMethods->[0]->instanceOf('PaymentMethod'),"$SubTestName - Test if the deleted PaymentMethod was PayPalExpress");
}

sub test_PPE_WrongViewAction {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $aPaymentMethods = ();
    my $PaymentMethodPayPalExpress = $self->_createPaymentMethod('DE_EPAGES::PayPalExpress::API::Object::PaymentMethodPayPalExpress', {
        'instanceOf' => 'PaymentMethodPayPalExpress',
        'IsDefault' => 0,
        'HidePayPalExpress' => 0,
        'HideInNormalCheckout' => 1,
    });
    push(@$aPaymentMethods, $PaymentMethodPayPalExpress);

    my $PaymentMethod = $self->_createPaymentMethod('DE_EPAGES::Payment::API::Object::PaymentMethod', {
        'instanceOf' => 'PaymentMethod',
        'IsDefault' => 1,
    });
    push(@$aPaymentMethods, $PaymentMethod);

    my $hParams = {
        'LineItemContainer' => $self->_createLineItemContainer('ViewSomethingElse'),
        'PaymentMethods' => $aPaymentMethods
    };

    DE_EPAGES::PayPalExpress::Hooks::LineItemContainer::OnLineItemContainerPaymentMethods($hParams);

    my $NumPayments = scalar(@$aPaymentMethods);
    is($NumPayments,2,"$SubTestName - Test if PayPalExpress was not deleted in this case");
}

sub test_PPE_HideExpressButton {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $aPaymentMethods = ();
    my $PaymentMethodPayPalExpress = $self->_createPaymentMethod('DE_EPAGES::PayPalExpress::API::Object::PaymentMethodPayPalExpress', {
        'instanceOf' => 'PaymentMethodPayPalExpress',
        'IsDefault' => 0,
        'HidePayPalExpress' => 1,
        'HideInNormalCheckout' => 1,
    });
    push(@$aPaymentMethods, $PaymentMethodPayPalExpress);

    my $PaymentMethod = $self->_createPaymentMethod('DE_EPAGES::Payment::API::Object::PaymentMethod', {
        'instanceOf' => 'PaymentMethod',
        'IsDefault' => 1,
    });
    push(@$aPaymentMethods, $PaymentMethod);

    my $hParams = {
        'LineItemContainer' => $self->_createLineItemContainer('ViewMultiCheckoutPayment'),
        'PaymentMethods' => $aPaymentMethods
    };

    DE_EPAGES::PayPalExpress::Hooks::LineItemContainer::OnLineItemContainerPaymentMethods($hParams);

    my $NumPayments = scalar(@$aPaymentMethods);
    is($NumPayments,2,"$SubTestName - Test if PayPalExpress was not deleted in this case");
}

sub test_PPE_DontHide {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $aPaymentMethods = ();
    my $PaymentMethodPayPalExpress = $self->_createPaymentMethod('DE_EPAGES::PayPalExpress::API::Object::PaymentMethodPayPalExpress', {
        'instanceOf' => 'PaymentMethodPayPalExpress',
        'IsDefault' => 0,
        'HidePayPalExpress' => 0,
        'HideInNormalCheckout' => 0,
    });
    push(@$aPaymentMethods, $PaymentMethodPayPalExpress);

    my $PaymentMethod = $self->_createPaymentMethod('DE_EPAGES::Payment::API::Object::PaymentMethod', {
        'instanceOf' => 'PaymentMethod',
        'IsDefault' => 1,
    });
    push(@$aPaymentMethods, $PaymentMethod);

    my $hParams = {
        'LineItemContainer' => $self->_createLineItemContainer('ViewMultiCheckoutPayment'),
        'PaymentMethods' => $aPaymentMethods
    };

    DE_EPAGES::PayPalExpress::Hooks::LineItemContainer::OnLineItemContainerPaymentMethods($hParams);

    my $NumPayments = scalar(@$aPaymentMethods);
    is($NumPayments,2,"$SubTestName - Test if PayPalExpress was not deleted in this case");
}

sub _createLineItemContainer {
    my $self = shift;
    my ($ViewAction) = @_;
    my $hAttributes = {
        'Parent' => $self->_createBasket($ViewAction),
    };
    my $MockifyLineItemContainer = DE_EPAGES::Test::Mock::MockifyEpagesObject->new( 'DE_EPAGES::Order::API::Object::LineItemContainer', $hAttributes );
    return $MockifyLineItemContainer->getMockObject();
}

sub _createBasket {
    my $self = shift;
    my ($ViewAction) = @_;
    my $hAttributes = {
        'instanceOf' => 'Basket',
        'CurrentViewAction' => $ViewAction,
    };
    my $MockifyBasket = DE_EPAGES::Test::Mock::MockifyEpagesObject->new( 'DE_EPAGES::Order::API::Object::Basket', $hAttributes );
    return $MockifyBasket->getMockObject();
}

sub _createPaymentMethod {
    my $self = shift;
    my ($Package, $hAttributes) = @_;
    my $MockifyPaymentMethod = DE_EPAGES::Test::Mock::MockifyEpagesObject->new( $Package, $hAttributes );
    return $MockifyPaymentMethod->getMockObject();
}

__PACKAGE__->runScript();