#========================================================================================
# package      DE_EPAGES::Product::t::unit::ProductService2
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::Product::API::ProductService
#               testing methods:
#               - getProductData()
#========================================================================================
package DE_EPAGES::Product::t::unit::ProductService2;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Product::API::ProductService;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::Mockify;
use DE_EPAGES::Test::Mock::Mockery;
use Test::More;
use feature qw ( switch );

use strict;



sub test {
    my $self = shift;

    $self->test_getProductData();

    done_testing();
}



sub test_getProductData {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $ProductService = $Mockery->get('SUT');
    my $Shop = $Mockery->get('Shop');
    my $Product = $Mockery->get('Product');

    my $LocaleID = 'de_DE';
    my $CurrencyID = 'EUR';

    my $hProductData = $ProductService->getProductData($Shop, $Product, $LocaleID, $CurrencyID);

    my $hExpectedProductData = $self->_createExpectedProductData();
    is_deeply($hProductData, $hExpectedProductData, "$SubTestName - test if expected data was returned.");
}



sub _createMocks {
    my $self = shift;

    my $Mockery = DE_EPAGES::Test::Mock::Mockery->new();

    $Mockery->register('SUT', ['Formatter', 'Locale', 'Context'], sub {
        my ($Formatter, $Locale, $Context) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Product::API::ProductService', []);
        $Mockify->addMockWithReturnValueAndParameterCheck('_createFormatter', $Formatter, ['object', 'string']);
        $Mockify->addMockWithReturnValueAndParameterCheck('_loadLocale', $Locale, ['string']);
        $Mockify->addMockWithReturnValueAndParameterCheck('_getShopContext', $Context, ['object']);
        return $Mockify->getMockObject();
    });
    $Mockery->register('Formatter', ['Shop'], sub {
        my ($Shop) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Shop::API::Resource::Formatter', [$Shop, 'de_DE']);
        $Mockify->addMock('price', sub {
            my $MockedSelf = shift;
            my ($Amount) = @_;
            return $Amount;
        });
        $Mockify->addMock('quantity', sub {
            my $MockedSelf = shift;
            my ($Amount) = @_;
            return $Amount;
        });
        $Mockify->addMock('bool', sub {
            my $MockedSelf = shift;
            my ($Amount) = @_;
            return $Amount;
        });
        return $Mockify->getMockObject();
    });
    $Mockery->register('Locale', [], sub {
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Object::API::Object::Locale', {
            'LanguageID' => '1',
        });
        return $Mockify->getMockObject();
    });
    $Mockery->register('Context', ['Shop'], sub {
        my ($Shop) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Shop::API::Resource::ShopRequestContext', [$Shop]);
        $Mockify->addMockWithReturnValue('apiBaseUrl', 'http://api.url.de');
        $Mockify->addMockWithReturnValue('imageBaseUrl', 'http://image.url.de');
        $Mockify->addMockWithReturnValueAndParameterCheck('validCurrency', 'EUR', [{'string'=>'EUR'}]);
        return $Mockify->getMockObject();
    });
    $Mockery->register('Shop', ['Product'], sub {
        my ($Product) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', {
            'Products' => [$Product],
            'TaxModel' => 1,
        });
        $Mockify->addMockWithReturnValueAndParameterCheck('siteLocale', undef, [{'string' => 'de_DE'}]);
        return $Mockify->getMockObject();
    });
    $Mockery->register('Product', [], sub {
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Product::API::Object::Product', {
            'AvailabilityText' => '',
            'AvailabilityIcon' => '',
            'IsAvailable' => 1,
            'IsVisible' => 1,
            'Description' => 'product description',
            'IsSpecialOffer' => '0',
            'Weight' => '123',
            'WeightUnit' => 'kg',
            'Text' => 'a product text',
            'NameOrAlias' => 'name or alias of the product',
            'ImageHotDeal' => 'TheProductImage_hotdeal.png',
            'ImageMedium' => 'TheProductImage_medium.png',
            'ImageLarge' => 'TheProductImage_large.png',
            'ImageSmall' => 'TheProductImage_small.png',
            'ImageThumbnail' => 'TheProductImage_thumb.png',
            'Path' => '/the/product/path/',
            'GUID' => '1236-363-3223324',
            'PriceQuantity' => '',
            'OrderUnit' => '',
            'RefUnit' => '',
            'RefAmount' => '',
            'RefContentAmount' => '',
            'ShippingMethods' => [],
            'WebPath' => 'http://webpath.test.url',
            'WebUrl' => 'http://web.test.url',
            'EnergyLabelsString' => '',
            'EnergyLabelSourceFile' => '',
            'ProductDataSheet' => '',
            'Alias' => 'AProduct',
            'UPCEAN' => '123-456-678',
            'Manufacturer' => 'the manufacturer of this product',
            'MainCharacteristics' => 'some main characteristics',
            'Keywords' => 'key, words, tags',
            'UserDefinedAttributeValues' => [],
            'UseSlideshow' => 1,
        });
        ## no critic (ProhibitMagicNumbers)
        $Mockify->addMockWithReturnValueAndParameterCheck('getListPrice', 12.3, [{'string'=>'EUR'}, {'int'=>1}]);
        $Mockify->addMockWithReturnValueAndParameterCheck('getManufacturerPrice', 23.4, [{'string'=>'EUR'}, {'int'=>1}]);
        $Mockify->addMockWithReturnValueAndParameterCheck('getEcoParticipation', 34.5, [{'string'=>'EUR'}, {'int'=>1}]);
        $Mockify->addMockWithReturnValueAndParameterCheck('getDeposit', 45.6, [{'string'=>'EUR'}, {'int'=>1}]);
        $Mockify->addMockWithReturnValueAndParameterCheck('getReferencePrice', undef, [{'string'=>'EUR'}, 'any']);
        ## use critic (ProhibitMagicNumbers)
        $Mockify->addMockWithReturnValue('isMaster', 1);
        $Mockify->addMockWithReturnValue('existSubProductPrices', 0);
        return $Mockify->getMockObject();
    });

    return $Mockery->assemble();
}



sub _createExpectedProductData {
    return {
        'energyLabelSourceFile' => undef,
        'priceInfo' => {
            'ecoParticipationPrice' => '34.5',
            'depositPrice' => '45.6',
            'basePrice' => undef,
            'quantity' => '',
            'manufacturerPrice' => '23.4',
            'priceWithDeposits' => '92.4',
            'price' => '12.3'
        },
        'energyLabelsString' => '',
        'availability' => '',
        'sfUrl' => 'http://web.test.url',
        'deliveryWeight' => '123',
        'links' => [
            {
                'rel' => 'self',
                'href' => 'http://api.url.de/api/products/1236-363-3223324'
            },
            {
                'rel' => 'slideshow',
                'href' => 'http://api.url.de/api/products/1236-363-3223324/slideshow'
            },
            {
                'rel' => 'variations',
                'href' => 'http://api.url.de/api/products/1236-363-3223324/variations'
            },
            {
                'rel' => 'categories',
                'href' => 'http://api.url.de/api/products/1236-363-3223324/categories'
            }
        ],
        'searchKeywords' => [
            'key',
            'words',
            'tags'
         ],
        'upcEan' => '123-456-678',
        'availabilityText' => '',
        'productImage' => 'TheProductImage_large.png',
        'images' => [
            {
                'url' => 'http://image.url.dehttp://webpath.test.url/TheProductImage_hotdeal.png',
                'classifier' => 'HotDeal'
            },
            {
                'url' => 'http://image.url.dehttp://webpath.test.url/TheProductImage_medium.png',
                'classifier' => 'Medium'
            },
            {
                'url' => 'http://image.url.dehttp://webpath.test.url/TheProductImage_large.png',
                'classifier' => 'Large'
            },
            {
                'url' => 'http://image.url.dehttp://webpath.test.url/TheProductImage_small.png',
                'classifier' => 'Small'
            },
            {
                'url' => 'http://image.url.dehttp://webpath.test.url/TheProductImage_thumb.png',
                'classifier' => 'Thumbnail'
            }
        ],
        'name' => 'name or alias of the product',
        'productNumber' => 'AProduct',
        'productId' => '1236-363-3223324',
        'essentialFeatures' => 'some main characteristics',
        'description' => 'a product text',
        'forSale' => 0,
        'shippingMethodsRestrictedTo' => undef,
        'specialOffer' => '0',
        'manufacturer' => 'the manufacturer of this product',
        'shortDescription' => 'product description',
        'productDataSheet' => undef
    };
}

__PACKAGE__->runScript();