#========================================================================================
# package      DE_EPAGES::Product::t::unit::StockLevelResource
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::Product::API::Resource::ProductStockLevelResource
#========================================================================================
package DE_EPAGES::Product::t::unit::StockLevelResource;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Product::API::Resource::ProductStockLevelResource;
use DE_EPAGES::Test::Mock::EpagesObject;
use Test::Exception;
use Test::More;

use strict;



sub test {
    my $self = shift;

    $self->test_get_stocklevel_product();
    $self->test_get_stocklevel_bundleProduct();

    $self->test_put_stocklevel_product();
    $self->test_put_stocklevel_bundleProduct();

    done_testing();
}



sub test_get_stocklevel_product {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Product = $self->_createProduct();
    my $ProductStockLevelResource = DE_EPAGES::Product::API::Resource::ProductStockLevelResource->new();

    my $hResponse = $ProductStockLevelResource->get($Product);

    my $hExpectedResponse = $self->_createStockLevelResponse(15); ## no critic (ProhibitMagicNumbers)
    is_deeply($hResponse, $hExpectedResponse, "$SubTestName - test if response hash is correct");
}



sub test_get_stocklevel_bundleProduct {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Product = $self->_createBundleProduct();
    my $ProductStockLevelResource = DE_EPAGES::Product::API::Resource::ProductStockLevelResource->new();

    my $hResponse = $ProductStockLevelResource->get($Product);

    my $hExpectedResponse = $self->_createStockLevelResponse(15); ## no critic (ProhibitMagicNumbers)
    is_deeply($hResponse, $hExpectedResponse, "$SubTestName - test if response hash is correct");
}



sub test_put_stocklevel_product {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Product = $self->_createProduct();
    my $ProductStockLevelResource = DE_EPAGES::Product::API::Resource::ProductStockLevelResource->new();
    my $hRequest = $self->_createChangeStockLevelRequest();

    my $hResponse = $ProductStockLevelResource->put($Product, $hRequest);

    my $hExpectedResponse = $self->_createStockLevelResponse(12); ## no critic (ProhibitMagicNumbers)
    is_deeply($hResponse, $hExpectedResponse, "$SubTestName - test if response hash is correct");
}



sub test_put_stocklevel_bundleProduct {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Product = $self->_createBundleProduct();
    my $ProductStockLevelResource = DE_EPAGES::Product::API::Resource::ProductStockLevelResource->new();
    my $hRequest = $self->_createChangeStockLevelRequest();

    throws_ok( sub {
        $ProductStockLevelResource->put($Product, $hRequest)
    }, qr/BadRequest: Reason=stock level of bundle products are read-only./, ## no critic (ProhibitComplexRegexes)
    "$SubTestName - test if error is thrown when changing stocklevel of bundle product");
}



sub _createProduct {
    return DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Product::API::Object::Product', {
        'StockLevel' => 15,
        'IsBundleProduct' => 0,
    });
}



sub _createBundleProduct {
    return DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Product::API::Object::Product', {
        'StockLevel' => 15,
        'IsBundleProduct' => 1,
    });
}



sub _createChangeStockLevelRequest {
    return {
        'changeStocklevel' => -3,
    };
}



sub _createStockLevelResponse {
    my $self = shift;
    my ($StockLevel) = @_;
    return {
        'stocklevel' => $StockLevel,
    };
}

__PACKAGE__->runScript();