#========================================================================================
# package      DE_EPAGES::Product::t::unit::UpdatedProductsResource
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::Product::API::Resource::UpdatedProductsResource
#========================================================================================
package DE_EPAGES::Product::t::unit::UpdatedProductsResource;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Product::API::Resource::UpdatedProductsResource;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::Mockify;
use DE_EPAGES::Test::Mock::Mockery;
use Test::More;

use strict;



sub test {
    my $self = shift;

    $self->test_UpdatedProductsResource();

    done_testing();
}



sub test_UpdatedProductsResource {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createMocks();
    my $Resource = $Mockery->get('SUT');

    my $Shop = $Mockery->get('Shop');
    my $ResultsPerPage = 10; ## no critic (ProhibitMagicNumbers)
    my $Page = 1;
    my $LocaleID = 'de_DE';
    my $CurrencyID = 'EUR';
    my $AttributesUpdatedSince = undef;
    my $StockLevelUpdatedSince = undef;

    my $hData = $Resource->get($Shop, $ResultsPerPage, $Page, $LocaleID, $CurrencyID, $AttributesUpdatedSince, $StockLevelUpdatedSince);
    is_deeply($hData, $self->_createExpectedProductData(), "$SubTestName - test if expected product data was returned.");
}



sub _createMocks {
    my $self = shift;

    my $Mockery = DE_EPAGES::Test::Mock::Mockery->new();

    $Mockery->register('SUT', ['ProductService'], sub {
        my ($ProductService) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Product::API::Resource::UpdatedProductsResource', []);
        $Mockify->addMockWithReturnValue('_createProductService', $ProductService);
        return $Mockify->getMockObject();
    });
    $Mockery->register('ProductService', ['Product1', 'Product2'], sub {
        my ($Product1, $Product2) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Product::API::ProductService', []);
        $Mockify->addMockWithReturnValueAndParameterCheck('getProductData', {'data'=>'value'}, [
            {'object' => 'DE_EPAGES::Shop::API::Object::Shop'},
            {'object' => 'DE_EPAGES::Product::API::Object::Product'},
            {'string' => 'de_DE'},
            {'string' => 'EUR'},
        ]);
        my $aUpdatedProducts = [
            [$Product1, '2016-01-27 16:04:15'],
            [$Product2, '2016-01-25 13:52:57'],
        ];
        $Mockify->addMockWithReturnValueAndParameterCheck('getAllUpdatedProducts', $aUpdatedProducts, ['object', 'string', 'string']);
        return $Mockify->getMockObject();
    });
    $Mockery->register('Shop', [], sub {
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', {});
        $Mockify->addMockWithReturnValueAndParameterCheck('existsSiteLocale', 1, [{'string' => 'de_DE'}]);
        $Mockify->addMockWithReturnValueAndParameterCheck('existsCurrency', 1, [{'string' => 'EUR'}]);
        return $Mockify->getMockObject();
    });
    $Mockery->register('Product1', [], sub {
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Product::API::Object::Product', {});
        return $Mockify->getMockObject();
    });
    $Mockery->register('Product2', [], sub {
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Product::API::Object::Product', {});
        return $Mockify->getMockObject();
    });

    return $Mockery->assemble();
}



sub _createExpectedProductData {
    return {
        'page' => 1,
        'items' => [
            {
                'item' => {'data' => 'value'},
                'lastUpdated' => '2016-01-27 16:04:15',
            },
            {
                'item' => {'data' => 'value'},
                'lastUpdated' => '2016-01-25 13:52:57',
            }
        ],
        'resultsPerPage' => 10,
        'results' => 2
    };
}

__PACKAGE__->runScript();